@@ -15,9 +15,12 @@
 #include <cmath>
 
 #include "kget_debug.h"
-#include <KLocalizedString>
-#include <QDebug>
 
+#include <KIO/Job>
+#include <KIO/TransferJob>
+#include <KLocalizedString>
+
+#include <QDebug>
 #include <QTimer>
 
 Segment::Segment(const QUrl &src, const QPair<KIO::fileoffset_t, KIO::fileoffset_t> &segmentSize, const QPair<int, int> &segmentRange, QObject *parent)
